@@ -26,15 +26,18 @@ except NameError:
     base_dir = None
 
 __base_dir__ = base_dir
-
+__branch__ = None
 if base_dir is not None and os.path.exists(os.path.join(base_dir, ".git")):
     git_folder = os.path.join(base_dir, ".git")
     with open(os.path.join(git_folder, "HEAD")) as fp:
         ref = fp.read().strip()
     ref_dir = ref[5:]
     __branch__ = ref[16:]
-    with open(os.path.join(git_folder, ref_dir)) as fp:
-        __commit__ = fp.read().strip()
+    try:
+        with open(os.path.join(git_folder, ref_dir)) as fp:
+            __commit__ = fp.read().strip()
+    except FileNotFoundError:
+        __commit__ = None
 else:
     __commit__ = None
 
