@@ -6,7 +6,10 @@ from .__about__ import (
     __license__,
     __summary__,
     __title__,
+    __pkg_name__,
     __url__,
+    __branch__,
+    __base_dir__
 )
 from .__version__ import __version__
 
@@ -18,8 +21,11 @@ __all__ = [
     "__license__",
     "__summary__",
     "__title__",
+    "__pkg_name__",
     "__url__",
     "__version__",
+    "__branch__",
+    "__base_dir__"
 ]
 
 from exorad.exorad import standard_pipeline
